var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import chokidar from 'chokidar';
import glob from 'fast-glob';
import fs from 'fs-extra';
import { join } from 'path';
import { outputFileMemo } from '../utils/outputFileMemo.js';
export function setupDoc(config, watch) {
    return __awaiter(this, void 0, void 0, function* () {
        const docUIPath = config.packageJson.name === 'react-doc-ui' ? '../src' : 'react-doc-ui';
        const rootDir = config.doc.root || '.';
        const include = config.doc.include || ['**/*.md', '**/*.mdx'];
        const exclude = [
            ...(config.doc.exclude || []),
            '**/node_modules/**',
            '**/build/**',
            '**/dist/**',
        ];
        yield fs.mkdirp('.rive');
        yield fs.outputFile(join(process.cwd(), '.rive', 'index.html'), `<!DOCTYPE html>
<html>
<head>
  <meta charset="utf-8">
  <title>${config.doc.title}</title>
</head>
<body>
  <div id="root"></div>
  <script type="module" src="./index.jsx"></script>
</body>
</html>
`);
        yield fs.outputFile(join(process.cwd(), '.rive', 'index.jsx'), `
import React from 'react';
import { createRoot } from 'react-dom/client';
import App from './App';

createRoot(document.getElementById('root')).render(<App />);
`);
        const update = () => __awaiter(this, void 0, void 0, function* () {
            const files = yield glob(include, {
                ignore: exclude,
                cwd: rootDir,
            });
            yield outputFileMemo(join(process.cwd(), '.rive', 'App.jsx'), `
import React from 'react';
import DocUI from '${docUIPath}';
${files.map((file, index) => `import * as doc${index} from '../${join(rootDir, file)}'`).join(';\n')}

export default function App() {
  return (
    <DocUI
      docs={[ ${files.map((_file, index) => `doc${index}`).join(', ')} ]}
      basename="${config.doc.basename}"
      languages={${JSON.stringify(config.doc.languages)}}
    />
  );
}
`);
        });
        yield update();
        if (watch) {
            const watcher = chokidar.watch(include, {
                ignored: exclude,
                cwd: rootDir,
                persistent: true,
            });
            watcher.on('change', () => update());
            watcher.on('add', () => update());
        }
    });
}
