var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import git from 'simple-git';
import { parseConfig } from '../config/parseConfig.js';
import { doESLint } from './doESLint.js';
import { doPrettier } from './doPrettier.js';
export function lint({ fix, staged }) {
    return __awaiter(this, void 0, void 0, function* () {
        const config = yield parseConfig();
        const stagedFiles = staged ? (yield git().status()).files : undefined;
        const stagedFilesToLint = stagedFiles === null || stagedFiles === void 0 ? void 0 : stagedFiles.filter((file) => ['A', 'M', 'R'].includes(file.index) &&
            ['.css', '.js', '.jsx', '.less', '.scss', '.ts', '.tsx'].some((ext) => file.path.endsWith(ext))).map((file) => file.path);
        if (fix) {
            doPrettier(stagedFilesToLint);
        }
        const eslintOk = yield doESLint(config, fix, stagedFilesToLint === null || stagedFilesToLint === void 0 ? void 0 : stagedFilesToLint.filter((file) => ['.js', '.jsx', '.ts', '.tsx'].some((ext) => file.endsWith(ext))));
        if (fix && stagedFilesToLint) {
            git().add(stagedFilesToLint);
        }
        if (!eslintOk) {
            process.exitCode = 1;
        }
    });
}
